#pragma comment(linker, "/STACK:64000000")

#include <algorithm>
#include <cstdlib>
#include <fstream>
#include <iostream>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, -1, 0, 1};

void dfs(int i, int j, const vector<string> &a, vector<vector<int> >& vis)
{
    vis[i][j] = 1;
    for (int d = 0; d < 4; d++) {
        if (a[i][j] == '#' && dy[d]) continue;
        int _i = i + dx[d];
        int _j = j + dy[d];
        if (_i < 0 || _j < 0 || _i >= a.size() || _j >= a[0].length()) continue;
        if (a[i][j] == 'X' && a[_i][_j] == '#' && dy[d]) continue;
        if (a[_i][_j] == '.') continue;
        if (vis[_i][_j]) continue;
        dfs(_i, _j, a, vis);
    }
}

pair<bool, string> check(const vector<string> &in, const vector<string> &out, int &cost)
{
    if (in.size() != out.size() || in[0].length() != out[0].length()) {
        return make_pair(false, "size is different");
    }
    
    int n = in.size(), m = in[0].length();
    int i, j, k;
    
    for (i = 1; i < n; i++) {
        if (out[i].length() != out[0].length()) {
            return make_pair(false, "solution is not rectangular");
        }
    }
    
    for (i = 0; i < n; i++) {
        for (j = 0; j < m; j++) {
            if (out[i][j] != '.' && out[i][j] != 'X' && out[i][j] != '#')
                return make_pair(false, "illegal character");
            if (out[i][j] == 'X' && in[i][j] == '.' || out[i][j] == '.' && in[i][j] == 'X')
                return make_pair(false, "X <=> .");
            if (out[i][j] == 'X' && in[i][j] == '#' || out[i][j] == '#' && in[i][j] == 'X')
                return make_pair(false, "# <=> X");
            if (!i) {
                if (out[i][j] == '#') return make_pair(false, "# at the top");
            } else {
                if (out[i][j] == '#' && out[i-1][j] == '.') return make_pair(false, "# below .");
            }
            if (i == n-1) {
                if (out[i][j] == '#') return make_pair(false, "# at the bottom");
            } else {
                if (out[i][j] == '#' && out[i+1][j] == '.') return make_pair(false, "# above .");
            }
        }
    }
    
    vector<vector<int> > vis(n, vector<int>(m));
    bool ok = 0;
    for (i = 0; i < n; i++) {
        for (j = 0; j < m; j++) {
            if (out[i][j] == 'X') {
                dfs(i, j, out, vis);
                ok = 1;
                break;
            }
        }
        if (ok) break;
    }
    for (i = 0; i < n; i++) {
        for (j = 0; j < m; j++) {
            if (out[i][j] != '.' && !vis[i][j]) {
                return make_pair(false, "not connected");
            }
        }
    }
    
    cost = 0;
    for (i = 0; i < n; i++)
        for (j = 0; j < m; j++)
            if (in[i][j] != out[i][j])
                cost++;
    
    return make_pair(true, "ok");
}

int main(int argc, char* argv[])
{
    ifstream f_in(argv[1]);
    ifstream f_out(argv[2]);
    ifstream f_ans(argv[3]);

    int m, n;
    f_in >> m >> n;
    vector<string> in(n);
    for (int i = 0; i < n; i++) f_in >> in[i];
    vector<string> out(n);
    for (int i = 0; i < n; i++) f_out >> out[i];
    vector<string> ans(n);
    for (int i = 0; i < n; i++) f_ans >> ans[i];
    
    int cost_out;
    pair<bool, string> res_out = check(in, out, cost_out);

    int cost_ans;
    pair<bool, string> res_ans = check(in, ans, cost_ans);
    
    if (!res_ans.first) {
        cout << "jury got WA: " << res_ans.second << endl;
        return 3; 
    }

    if (!res_out.first) {
        cout << "WA: " << res_out.second << endl;
        return 1; 
    }
    
    if (cost_ans > cost_out) {
        cout << "jury cost is more: " << cost_ans << " " << cost_out << endl;
        return 3; 
    }

    if (cost_ans < cost_out) {
        cout << "jury cost is less: " << cost_ans << " " << cost_out << endl;
        return 1; 
    }
    
    cout << "ok" << endl;
    return 0;
}

