#include <algorithm>
#include <cstdlib>
#include <iomanip>
#include <iostream>
#include <fstream>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, -1, 0, 1};

const int tests_start = 11;

ofstream out;
int current_test;

void new_test()
{
    if (current_test >= tests_start) out.close();
    current_test++;
    ostringstream ss;
    ss << setfill('0') << setw(2) << current_test;
    out.open(ss.str().c_str());
    cout << ss.str() << endl;
}

bool is_neib_free(const vector<string>& res, int i, int j)
{
    if (res[i][j] == 'X') return false;
    for (int sc = 0; sc < 4; sc++)
        if (res[i + dx[sc]][j + dy[sc]] == 'X') return false;
    return true;
}

vector<string> gen(int n, int m, double p, double q, int max_len)
{
    vector<string> res(n+2);
    int i, j;
    for (i = 0; i < n+2; i++)
        for (j = 0; j < m+2; j++)
            res[i] += ".";
    
    int num = 0;
    int x = 0;
    int L = m; 
    int R = -1;
    while (num < 1000) {
        num++;
        i = rand() % n + 1;
        j = rand() % m + 1;
        int k = 0;
        while (j+k-1 < m && is_neib_free(res, i, j+k)) {
            k++;        
        }
        if (!k) continue;
        if (k > max_len) k = max_len;
        k = 1 + rand() % k;

        //а так мы обеспечиваем связность
        if (L != m && (j+k-1 < L || j > R)) continue;
        if (j+k-1 > R) R = j+k-1;
        if (j < L) L = j;
        
        num = 0;
        for (int sc = 0; sc < k; sc++) {
            res[i][j+sc] = 'X';
            x++;
        }
        if (x >= n*m*p) break;
    }
    
    int num1 = 0;
    int x1 = 0;
    while (num1 < 1000) {
        num1++;
        i = rand() % n + 1;
        j = rand() % m + 1;
        if (res[i][j] != '.') continue;
        
        num1 = 0;
        if (x1 >= n*m*q) break;
        res[i][j] = '#';
        x1++;
        if (x1 >= n*m*q) break;
    }

    vector<string> res1;
    for (i = 1; i <= n; i++)
        res1.push_back(res[i].substr(1, m));
    
    return res1;
}

vector<string> gen_chess(int n, int m)
{
    vector<string> res(n);
    int i, j;
    
    for (i = 0; i < n; i++)
        for (j = 0; j < m; j++)
            res[i].push_back('.');
    
    for (j = 0; j < m; j++) {
        res[n-1][j] = 'X';
    }
    
    //предпоследний слой нужно не рисовать, а то будут X-ы друг над другом
    for (i = 0; i < n-2; i++)
        for (j = 0; j < m; j++)
            if ((i+j) % 2) res[i][j] = 'X';

    return res;
}

void output(const vector<string>& a)
{
    new_test();
    
    out << a[0].length() << " " << a.size() << endl;
    for (int i = 0; i < a.size(); i++)    
        out << a[i] << endl;
}

int main()
{
    current_test = tests_start-1;
    srand(435551);
    
    output(gen(10, 10, 0.2, 0.1, 7));
    output(gen_chess(10, 10));
    output(gen(10, 10, 0.5, 0.1, 10));
    output(gen(20, 20, 0.5, 0.1, 20));
    output(gen(20, 20, 0.3, 0.1, 20));
    output(gen(100, 100, 0.3, 0.1, 2));
    output(gen(100, 100, 0.3, 0.1, 100));
    output(gen(100, 100, 0.3, 0.5, 100));
    output(gen(100, 100, 0.3, 1.0, 100));
    output(gen(1000, 1000, 0.1, 0.0, 1000));
    output(gen(1000, 1000, 0.1, 0.1, 1000));
    output(gen(1000, 1000, 0.1, 0.9, 1000));
    output(gen(1000, 1000, 0.3, 0.1, 1000));
    output(gen(1000, 1000, 0.3, 0.1, 2));
    output(gen(1000, 1000, 0.5, 0.1, 10));
    output(gen(1000, 1000, 0.7, 0.0, 10));
    output(gen(1000, 1000, 0.7, 0.2, 10));
    output(gen(1000, 1000, 0.7, 0.8, 2));
    output(gen(1000, 1000, 0.7, 0.2, 2));
    output(gen(1000, 1000, 0.7, 0.2, 1000));
    output(gen_chess(1000, 1000));
}

