#pragma comment(linker, "/STACK:64000000")

#include <algorithm>
#include <cstdlib>
#include <cstdio>
#include <iostream>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, -1, 0, 1};

struct edge
{
    int u, v, j, w, take;
    
    edge(int _u, int _v, int _j, int _w, int _take): u(_u), v(_v), j(_j), w(_w), take(_take) {}
};

bool edge_less(const edge& a, const edge& b)
{
    return a.w < b.w;
}

int find_parent(int x, vector<int>& p)
{
    if (p[x] != x) p[x] = find_parent(p[x], p);
    return p[x];
}

void join(int x, int y, vector<int>& p, vector<int>& r)
{
    if (r[x] >= r[y]) {
        p[y] = x;
        if (r[x] == r[y]) r[x]++;
    } else {
        p[x] = y;
    }
}

vector<string> solve(const vector<string> &a)
{
    vector<string> res = a;
    int n = res.size();
    int m = res[0].length();
    
    int i, j, k;
    
    //нумеруем платформы и формируем рёбра
    k = 0;
    vector<vector<int> > cc(n, vector<int>(m));
    vector<int> start_i(1);
    vector<edge> eds;
    for (j = 0; j < m; j++) {
        int last = -1;
        int lc = 0;
        for (i = 0; i < n; i++) {
            if (res[i][j] == '#') lc++;
            if (res[i][j] == 'X') {
                int cur;
                if (j && res[i][j-1] == 'X')
                    cur = cc[i][j] = cc[i][j-1];
                else {
                    k++;
                    cur = cc[i][j] = k;
                    start_i.push_back(i);
                }
                if (last != -1) {
                    int rest = i-start_i[last]-1-lc;
                    int w =  rest - lc;
                    eds.push_back(edge(last, cur, j, w, lc >= rest));
                }
                last = cur;
                lc = 0;
            }
        }
    }
    
    //берём сначала рёбра, которые в любом случае надо взять
    //потом ищем минимальный остов алгоритмом Краскала
    //сразу дорисовываем взятые лестницы
    sort(eds.begin(), eds.end(), edge_less);
    vector<int> p(k+1), r(k+1);
    for (i = 1; i <= k; i++)
        p[i] = i;
    for (int pass = 0; pass < 2; pass++) {
        for (i = 0; i < eds.size(); i++) {
            int u = eds[i].u, pu = find_parent(u, p);
            int v = eds[i].v, pv = find_parent(v, p);
            if (pass == 0 && eds[i].take || pass == 1 && pu != pv) {
                join(pu, pv, p, r);
                for (int sc = start_i[u]+1; sc < start_i[v]; sc++) //полагаемся на порядок u-v
                    res[sc][eds[i].j] = '#';
            }
        }
    }
    
    //остальные куски лестниц выкидываем
    for (j = 0; j < m; j++) {
        for (int d = -1; d <= 1; d++) {
            if (!d) continue;
            int last = -1;
            int start = -1, finish = n;
            if (d < 0) swap(start, finish);
            for (i = start+d; i != finish; i += d) {
                if (res[i][j] == '#' && last == -1) res[i][j] = '.';
                if (res[i][j] == 'X') last = i;
                if (res[i][j] == '.') last = -1;
            }
        }
    }
    
    return res;
}

int main()
{
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
    
    int i, n, m;
    cin >> m >> n;
    vector<string> v(n);
    for (i = 0; i < n; i++)
        cin >> v[i];
        
    vector<string> ans = solve(v);
    
    for (i = 0; i < n; i++)
        cout << ans[i] << endl;
    
    fclose(stdin);
    fclose(stdout);
}
